##  Synchronization Scope
Synchronization directions:
Source System | Target System | Supported Fact Sheet Types
---|---|---
SAP LeanIX | Jira Service Management | Applications and subtypes
Jira Service Management |  SAP LeanIX | IT components and subtypes


Supported attributes:
  * Only text fields are supported in the initial release.
  * User, Object, and Value fields are not supported.
